@@ -103,6 +103,7 @@ extern "C"
 //
 // guint16, guint32:
 //
+typedef unsigned char guint8;
 #ifdef _WIN32
   #if defined(__MINGW32__) || defined(__MINGW64__)
     #include <stdint.h>
@@ -316,6 +317,25 @@ G_END_DECLS
 // END gtypes.h
 //
 
+//
+// BEGIN gtestutils.h
+//
+int     g_strcmp0                       (const char     *str1,
+                                         const char     *str2);
+//
+// END gtestutils.h
+//
+
+//
+// BEGIN gmessages.h
+//
+// we're not debugging here, so..
+#define g_return_if_fail(expr)          if(!(expr))return;
+#define g_return_val_if_fail(expr,val)  if(!(expr))return(val);
+//
+// END gmessages.h
+//
+
 //
 // BEGIN gquark.h
 //
@@ -734,9 +754,10 @@ typedef enum
   G_FILE_TEST_IS_DIR        = 1 << 2
 } GFileTest;
 
-gboolean g_file_test         (const gchar  *filename,
-                              GFileTest     test);
+gboolean g_file_test        (const gchar  *filename,
+                             GFileTest     test);
 
+#define g_dirname(filename) g_path_get_dirname(filename)
 G_END_DECLS
 //
 // END gfileutils.h
@@ -768,10 +789,27 @@ GList*   g_list_append                  (GList            *list,
 					 gpointer          data) G_GNUC_WARN_UNUSED_RESULT;
 GList*   g_list_prepend                 (GList            *list,
 					 gpointer          data) G_GNUC_WARN_UNUSED_RESULT;
+GList*   g_list_concat                  (GList            *list1,
+					 GList            *list2) G_GNUC_WARN_UNUSED_RESULT;
+GList*   g_list_remove                  (GList            *list,
+					 gconstpointer     data) G_GNUC_WARN_UNUSED_RESULT;
+GList*   g_list_remove_link             (GList            *list,
+					 GList            *llink) G_GNUC_WARN_UNUSED_RESULT;
+GList*   g_list_delete_link             (GList            *list,
+					 GList            *link_) G_GNUC_WARN_UNUSED_RESULT;
+GList*   g_list_reverse                 (GList            *list) G_GNUC_WARN_UNUSED_RESULT;
+GList*   g_list_copy                    (GList            *list) G_GNUC_WARN_UNUSED_RESULT;
+GList*   g_list_find                    (GList            *list,
+					 gconstpointer     data);
 GList*   g_list_last                    (GList            *list);
 void     g_list_foreach                 (GList            *list,
 					 GFunc             func,
 					 gpointer          user_data);
+GList*   g_list_sort                    (GList            *list,
+					 GCompareFunc      compare_func) G_GNUC_WARN_UNUSED_RESULT;
+
+#define g_list_previous(list)	          ((list) ? (((GList *)(list))->prev) : NULL)
+#define g_list_next(list)	              ((list) ? (((GList *)(list))->next) : NULL)
 
 G_END_DECLS
 //
@@ -840,12 +878,19 @@ void	    g_hash_table_destroy	   (GHashTable	   *hash_table);
 void	    g_hash_table_insert		   (GHashTable	   *hash_table,
 					    gpointer	    key,
 					    gpointer	    value);
+void        g_hash_table_replace           (GHashTable     *hash_table,
+                                            gpointer        key,
+                                            gpointer        value);
 //currently unused..
 //gboolean    g_hash_table_remove		   (GHashTable	   *hash_table,
 //					    gconstpointer   key);
 void        g_hash_table_remove_all        (GHashTable     *hash_table);
 gpointer    g_hash_table_lookup		   (GHashTable	   *hash_table,
 					    gconstpointer   key);
+gboolean    g_hash_table_lookup_extended   (GHashTable     *hash_table,
+                                            gconstpointer   lookup_key,
+                                            gpointer       *orig_key,
+                                            gpointer       *value);
 void	    g_hash_table_foreach	   (GHashTable	   *hash_table,
 					    GHFunc	    func,
 					    gpointer	    user_data);
